@@ -103,7 +103,7 @@ extern "C" {
 
 /** the version of this header file */
 #define UNBOUND_VERSION_MAJOR 1
-#define UNBOUND_VERSION_MINOR 21
+#define UNBOUND_VERSION_MINOR 22
 #define UNBOUND_VERSION_MICRO 0
 
 /**
@@ -845,6 +845,10 @@ struct ub_server_stats {
 	long long qtls_resume;
 	/** RPZ action stats */
 	long long rpz_action[UB_STATS_RPZ_ACTION_NUM];
+	/** number of bytes in QUIC buffers */
+	long long mem_quic;
+	/** number of queries over (DNS over) QUIC */
+	long long qquic;
 };
 
 /**
